# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['apilytics']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'apilytics',
    'version': '1.6.0',
    'description': 'Apilytics for Python - Easy API analytics for Python backends',
    'long_description': '# Apilytics for Python\n\n[![pypi](https://img.shields.io/pypi/v/apilytics)](https://pypi.org/project/apilytics/)\n[![ci](https://github.com/apilytics/apilytics-python/actions/workflows/ci.yml/badge.svg)](https://github.com/apilytics/apilytics-python/actions/workflows/ci.yml)\n[![codecov](https://codecov.io/gh/apilytics/apilytics-python/branch/master/graph/badge.svg?token=GIW1NZ7UAJ)](https://codecov.io/gh/apilytics/apilytics-python)\n[![mypy checked](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org)\n[![code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n[![python versions](https://img.shields.io/pypi/pyversions/apilytics)](#what-python-versions-does-the-package-work-with)\n[![license](https://img.shields.io/pypi/l/apilytics.svg)](https://github.com/apilytics/apilytics-python/blob/master/LICENSE)\n\nApilytics is a service that lets you analyze operational, performance and security metrics from your APIs easily.\n\n<img src="https://www.apilytics.io/mock-ups/time-frame.gif" alt="Apilytics dashboard animation" width="600" height="300" />\n\n## Installation\n\n1. Sign up and get your API key from https://apilytics.io - we offer a completely free trial with no credit card required!\n\n2. Install this package:\n\n```sh\npip install apilytics\n```\n\n3. Enable the middleware and set your API key:\\\n   _A good practice is to securely store the API key as an environment variable.\n   You can leave the env variable unset in e.g. development and test environments,\n   the middleware will be automatically disabled if the key is `None`._\n\n### Django\n\n`settings.py`:\n\n```python\nimport os\n\nAPILYTICS_API_KEY = os.getenv("APILYTICS_API_KEY")\n\nMIDDLEWARE = [\n    "apilytics.django.ApilyticsMiddleware",  # Ideally the first middleware in the list.\n    # ...\n]\n```\n\n### FastAPI\n\n`main.py`:\n\n```python\nimport os\n\nfrom apilytics.fastapi import ApilyticsMiddleware\nfrom fastapi import FastAPI\n\napp = FastAPI()\n\n# Ideally the last middleware you add.\napp.add_middleware(ApilyticsMiddleware, api_key=os.getenv("APILYTICS_API_KEY"))\n```\n\n### Flask\n\n`app.py`:\n\n```python\nimport os\n\nfrom apilytics.flask import apilytics_middleware\nfrom flask import Flask\n\napp = Flask(__name__)\n\n# Ideally wrap your app with the middleware before you do anything else with it.\napp = apilytics_middleware(app, api_key=os.getenv("APILYTICS_API_KEY"))\n```\n\n### Other Python Frameworks\n\nYou can easily build your own middleware which measures the execution time and sends the metrics:\n\n`my_apilytics_middleware.py`:\n\n```python\nimport os\n\nfrom apilytics.core import ApilyticsSender\n\n\ndef my_apilytics_middleware(request, get_response):\n    api_key = os.getenv("APILYTICS_API_KEY")\n    if not api_key:\n        return get_response(request)\n\n    with ApilyticsSender(\n        api_key=api_key,\n        path=request.path,\n        query=request.query_string,\n        method=request.method,\n        request_size=len(request.body),\n        user_agent=request.headers.get("user-agent"),\n        ip=request.headers.get("x-forwarded-for", "").split(",")[0].strip(),\n    ) as sender:\n        response = get_response(request)\n        sender.set_response_info(\n            status_code=response.status_code,\n            response_size=len(response.body),\n        )\n    return response\n```\n\n## Frequently Asked Questions\n\n### Does the middleware slow down my backend?\n\n- No. The middleware does all of its requests to the Apilytics API in a background thread pool,\n  so it will not slow down your normal request handling.\n\n### What 3rd party dependencies does `apilytics` have?\n\n- None besides the frameworks that you use it in.\n\n### What Python versions does the package work with?\n\n- `apilytics` is tested to work on all the currently [supported versions of Python](https://devguide.python.org/#status-of-python-branches): 3.7, 3.8, 3.9, and 3.10.\n',
    'author': 'Apilytics',
    'author_email': 'hello@apilytics.io',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://apilytics.io',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
